clear all
pause on

** Modify next line to filepath to "Replication Files" folder
global dir "$path_db/Annual Review -- Intergroup Contact/Replication Files"

cd "$dir/data/raw"
global datapath "$dir/data"
global figpath "$dir/figures"
global tabpath "$dir/tables"

graph set window fontface "Times New Roman"

local rho = 12 // =12 for core results, =0 or 80 for robustness (only run killerfig switch with rho=0 or 80)
local samples = 8 // keep at 8 for the results in the paper, see collapse switch for additional criteria used for samples>8 

local all=1

if `all'==0 {
	local check_eligible	0
	local check_papers		0
	local check_effects		0
	local collapse			0
	local biascheck			0
	local killerfig			1
	local genprob			0
	local bundVclean		0
	local exphet			0
	local globalsouth		0
	local onlineVoff		0
	local compare_clochard	0
}
if `all'==1 {
	local check_eligible	1
	local check_papers		1
	local check_effects		1
	local collapse			1
	local biascheck			1
	local killerfig			1
	local genprob			1
	local bundVclean		1
	local exphet			1
	local globalsouth		1
	local onlineVoff		1	
	local compare_clochard	1
}

if `check_eligible'==1 { // Check eligible pre-registrations
	
	use "$datapath/raw/1_lowe_contact_eligible_preregs", clear
	
	/* output needed for Annual Review paper */
	
	** Formal check of eligibility criteria
	assert inlist(registry,"AEA","EGAP","OSF") & prereg_before_analy==1 & rand_intergroup==1 & prej_outcome==1 & prereg_year<2024
	
	** How many pre-registrations did we find? (note includes some duplicates)
	count
	
	** How many eligible pre-registered experiments did we find?
	count if duplicate==0
	
	** How many of these did we find results for?
	count if duplicate==0 & paper_available==1
	
	*pause
	clear
}
if `check_papers'==1 { // Check eligible studies
	
	use "$datapath/raw/2_lowe_contact_studies", clear
	
	/* output needed for Annual Review paper */
	
	** How many papers do we have in total?
	count
	local Npapers=r(N)
	
	** How many experiments do we have in total?
	qui su Nexperiment2
	local Nextra=r(N)
	local Nexp = `Npapers'+`Nextra'
	di "`Nexp'"
		
	** How many countries?
	distinct country
	
	** How many participants?
	g max1 = sum(Nexperiment1)
	g max2 = sum(Nexperiment2)
	qui su max1
	local max1 = r(max)
	qui su max2
	local max2 = r(max)
	local totN = `max1'+`max2'
	drop max?
	di "Total participants = `totN'"
	
	** How many types of groups?
	tab contact_group1
	tab contact_group2
	distinct contact_group1
	
	** How many experiments have clean contact?
	count if treat_highVlow==1 | treat_someVno==1
	local Nclean = r(N)+2 // need to double-count Broockman-Kalla + Porat
	di "`Nclean'"
	
	** How many with bundled outgroup vs. control?
	count if treat_outgroupVctrl==1 // no double-counting needed here
	
	** How many with bundled ingroup vs. control?
	count if treat_ingroupVctrl==1
	*pause
	
	** How many experiments with >1 type of contact?
	tab more_than_one_type // no double-counting needed here
	
	** How many with mean age>=25?
	forv i=1/2 {
		count if !mi(mean_age`i') & mean_age`i'!=-99
		count if mean_age`i'>=25 & !mi(mean_age`i') & mean_age`i'!=-99
	}
		
	clear
}
if `check_effects'==1 { // Check treatment effects
	
	use "$datapath/raw/3_lowe_contact_effects", clear
	
	/* Checks of effects */
	
	di "How many papers are we collecting effects for?"
	distinct registry_paperID
	
	di "How many papers with at least one reported intergroup relations-related outcome?"
	distinct registry_paperID if outcome_in_paper==1 & !(outcome_type1=="Unrelated" & outcome_type2=="")
	
	di "What fraction of primary pre-specified intergroup relations outcomes are not found (in paper or replication files)?"
	preserve
		assert !mi(registry_expID)
		drop if outcome_type1=="Unrelated" & outcome_type2==""
		keep registry_expID primary_prereg_outcome outcome_in_paper
		
		** Drop timing references (since missing outcomes usually not coded with a timepoint)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Endline 1","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Endline 2","",.)		
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," -- 30 days","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," -- 210 days","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Follow up","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Endline","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Follow-up","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Post-meeting","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," T1","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," T2","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," T3","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," T4","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Short-term","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Long-term","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," - Two weeks","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," -- 1 day","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," -- 7 days","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," -- 30 days","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome," -- 120 days","",.)
		replace primary_prereg_outcome = subinstr(primary_prereg_outcome,"- Follow-up","",.)
		
		replace primary_prereg_outcome = trim(primary_prereg_outcome)
				
		duplicates drop
		isid registry_expID primary_prereg_outcome
		assert inlist(outcome_in_paper,1,0)
				
		** Outcome-level check
		su outcome_in_paper
				
		** Experiment-level check
		bys registry_expID: egen reported_mean = mean(outcome_in_paper)
		keep registry_expID reported_mean
		duplicates drop
		su reported_mean
		
		*pause
	restore
	
	di "How many effects?"
	preserve
		drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
		drop if outcome_type1=="Unrelated" & outcome_type2==""
		count
		*pause
		
		** How many effects on behavioral/incentivized outcomes? Differences across fields?
		tab behavioral_incent
		bys registry: tab behavioral_incent
		tab behavioral_incent if registry!="AEA"
		
		*pause
		
		** How many effects with clean variation?
		count if strpos(treatment_comparison,"High versus")
		distinct registry_expID if strpos(treatment_comparison,"High versus")
		*pause
		
		** How many contact experiments have delayed outcome measurement?		
		drop if days_until_measurement==0
		distinct registry_expID
		*pause
	restore
	
	** How many hours of interaction?
	preserve
		keep paper_authors paper_title paper_year contact_duration_best_guess
		drop if mi(contact_duration_best_guess)
		duplicates drop
	restore
	
	** What measurement timepoints?
	preserve
		drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
		keep if reg_before_analysis==1
		drop if outcome_type1=="Unrelated" & outcome_type2==""	
		keep registry paperID registry_paperID experimentID registry_expID days_until_measurement paper_authors paper_title
		duplicates drop
		*br
		*pause
	restore
	
	clear
}
if `collapse'==1 { // Collapse effects data to experiment-level

	use "$datapath/raw/3_lowe_contact_effects", clear
	
	** keep only effects with complete data
	drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
	
	** keep only if pre-registered prior to analysis
	keep if reg_before_analysis==1

	** keep only necessary variables
	keep registry paperID experimentID registry_paperID registry_expID paper_authors ///
		paper_title paper_year primary_prereg_outcome effectID collapseID groupID group_name outcome_type? ///
		generalized behavioral_incent comparisonID treatment_comparison ///
		treatment_comparison_notes contact_duration* days_until_measurement ///
		in_main_paper in_abstract effect_size se_std *allport* contact_type ///
		paper_authors_year online_contact global_south
		
	** never want the unrelated outcomes
	drop if outcome_type1=="Unrelated" & outcome_type2==""
		
	** loop over different inclusion criteria
	forv k=1/`samples' {
		preserve
		
			/** STEP 1: decide which outcomes/comparisons to keep **/
			
			if inrange(`k',1,4) { // clean comparison
				keep if strpos(treatment_comparison,"High versus low") | strpos(treatment_comparison,"High versus no")
				local lab "Clean"
			}
			if inrange(`k',5,8) { // bundled, outgroup versus control
				keep if strpos(treatment_comparison,"Outgroup contact bundled versus")			
				local lab "Bundled-Out"
			}	
			if inrange(`k',9,12) { // bundled, ingroup versus control
				keep if strpos(treatment_comparison,"Ingroup contact bundled versus")
				local lab "Bundled-In"
			}			
			if inlist(`k',2,3,4,6,7,8,10,11,12) { 
				keep if generalized==1
				local lab "`lab', Generalized"				
			}
			if inlist(`k',3,4,7,8,11,12) {
				keep if allport_conditions==4 & contact_type=="In-person"
				local lab "`lab', Optimal"						
			}			
			if inlist(`k',4,8,12) {
				keep if contact_duration_best_guess>=4
				local lab "`lab', Long"						
			}
			if `k'==13 { // keep most positive estimates in each experiment
				keep if strpos(treatment_comparison,"High versus low") | strpos(treatment_comparison,"High versus no")
				keep if generalized==1
				
				gsort registry_expID -effect_size
				by registry_expID: g size_order = _n
				keep if size_order==1
				
				local lab "Clean, Generalized, Best"										
			}	
			if `k'==14 { // keep only specific
				keep if strpos(treatment_comparison,"High versus low") | strpos(treatment_comparison,"High versus no")
				keep if generalized==0
								
				local lab "Clean, Specific"
			}
			tempfile step1
			save `step1', replace
						
			* double-check no more than one treatment comparison type per experiment
			keep registry_expID treatment_comparison
			duplicates drop
			isid registry_expID
			use `step1', clear
						
			/** STEP 2: collapse to experiment-endpoint level **/
			* Collapsing when effects are estimated separately for different groups (e.g. Locals vs. Refugees)
			* or when two separate comparisons for effects on same outcome (e.g. as in Chaudhry-Hussain)
			* here we collapse assuming independence, giving us roughly what we would get had the authors ran a pooled regression				
			
			* (note that the approach here is not perfect: e.g. in some cases will end up with one effect on one group, and another
			* on the pooled groups, and these two effects will then get collapsed in the next step as if they were both effects on 
			* the pooled groups. but this happens very rarely, and even when it happens would barely change the collapsed SE)
			
			* Find experiments eligible for this collapse
			bys registry_expID collapseID: g groupN = _N
			distinct registry_expID if groupN>1 // max. 8 experiments				
			
			* Case A: same endpoint, effects estimated for different groups
			* Barros (IDP vs. Locals)
			* Mackenna (Low vs. High SES)
			* Porat et al. (2 experiments, Jewish vs. Palestinian)	
			
			* Case B: 
			* Paler et al. (4 comparisons: effect of mixed-sect and effect of mixed-class)
				// we collapse (1) vs (2) together with (3) vs (4) assuming independence
				// similarly can collapse (1) vs (3) together with (2) vs (4) assuming independence
				// note endpointID=2 has some sample overlap when we collapse				
				// then the question is: what is the correlation between 
				// 1/2(M3 + M4 - M1 - M2) and 1/2(M2 + M4 - M1 - M3)
				// looks like it cancels out to zero, in which case code is already correct
				// one way to think about it is that the two sets of comparisons are orthogonal to one another
			* Scacco and Warren (2 comparisons: homog vs. het classroom, homog vs. het partner)
				// like Paler et al. endpoint ID 2, there is some sample overlap
				// first comparison: 1/2(0.5*Mhet_hom + 0.5*Mhet_het - Mhomog)
				// second comparison: 1/2(Mhet_het - Mhet_hom)
				// correlation again appears to net out to zero because comparisons are orthogonal to one another
				// note ref is Chapter 25 of Borenstein
			* Chaudhry and Hussain (2 comparisons: Contact vs. Control and Combined vs. Leadership)
			
			* Case C: different endpoint, effects estimated for different groups
			* collapseID is coded slightly differently to effectID to ensure these different endpoints get collapsed
			* assuming independence, to the extent possible
			* Barros (IDPs vs. Locals)
			* Abril et al. (Citizens vs. Police)
			* Loiacono and Silva-Vargas (Local vs. Refugee)
			
			* for simplicity, no weighting by sample size of different groups (often they are similar anyway)
			bys registry_expID collapseID: egen exp_out_effect_size = mean(effect_size) 
						
			g se_std_sq = se_std^2	
			bys registry_expID collapseID: egen se_std_sq_sum_exp_out = total(se_std_sq)
			g exp_out_se_std = sqrt((1/groupN)^2*se_std_sq_sum_exp_out)	// this is where we assume independence (i.e. rho=0)
			
			tab paper_authors_year if se_std!=exp_out_se_std
			
			* Store averages of some important variables that differ in the rare cases where we collapse different endpoints
			assert inlist(behavioral_incent,0,0.5,1)
			bys registry_expID collapseID: egen behavioral_incent_meanTmp = mean(behavioral_incent)
			assert inlist(generalized,0,1)
			bys registry_expID collapseID: egen generalized_meanTmp = mean(generalized)
			assert !mi(days_until_measurement)
			bys registry_expID collapseID: egen days_until_meas_meanTmp = mean(days_until_measurement)
						
			* Can now collapse the data to experiment-by-endpoint level
			drop effectID effect_size se_std groupN se_std_sq se_std_sq_sum_exp_out treatment_comparison_notes days_until_measurement ///
				groupID group_name comparisonID in_main_paper in_abstract behavioral_incent primary_prereg_outcome outcome_type? generalized ///
							
			duplicates drop
			isid registry_expID collapseID
			distinct registry_expID

			
			/** STEP 3: collapse to experiment-level **/
			
			** get average of some important variables for each experiment
			foreach x in behavioral_incent generalized days_until_meas {
				bys registry_expID: egen `x'_mean_s`k' = mean(`x'_meanTmp)
				drop `x'_meanTmp
			}
			
			** get average effect size for each experiment	
			bys registry_expID: egen exp_effect_size = mean(exp_out_effect_size) 
			g exp_se_std=.	
			
			bys registry_expID: g endpointN = _N
									
			** weighting cases
			* Case A: 1 outcome per experiment, no weighting (e.g. Finseraas and Kotsadam)
			replace exp_se_std = exp_out_se_std if endpointN==1

			* Case B(i): Different outcomes measured at same time point (e.g. Lowe)
			* Borenstein et al. 2009 chapter 24 -- multiple outcomes or time-points within a study
			* And equation (6) in Lund et al. (pg60)
			
			* Case B(ii): Same outcome measured at different time points (e.g. Broockman and Kalla)
			* Borenstein p225: "For our purposes... multiple outcomes for the same subjects or multiple time-points 
			* for the same subjects... are identical"			
			
			* Case B(iii): Both (e.g. Ghosh et al.)		
			g se_std_sq = exp_out_se_std^2
			bys registry_expID: egen se_std_sq_sum = total(se_std_sq)
			bys registry_expID: g endpoint_order = _n
			g endpointN_sq = endpointN^2
			
			qui su endpointN
			local maxend = r(max)
			forv i=1/`maxend' {
				g se_std`i'_tmp = exp_out_se_std if endpoint_order==`i'
				bys registry_expID: egen se_std`i' = max(se_std`i'_tmp)
				drop se_std`i'_tmp
			}
			
			forv i=1/`maxend' {
				g se_std`i'_sumsq = 0
				
				forv j=1/`maxend' {
					replace se_std`i'_sumsq = se_std`i'_sumsq + (se_std`i'*se_std`j') if !mi(se_std`i') & !mi(se_std`j')
				}
				
				replace se_std`i'_sumsq = se_std`i'_sumsq - se_std`i'^2
			}
			egen sumsq_cross_se = rowtotal(se_std*_sumsq)
			
			foreach x in 0 10 12 15 20 40 60 80 { // range of possible correlations between effect sizes
				local corr = `x'/100		
				g exp_se_std`x'=exp_se_std
				replace exp_se_std`x'=sqrt((1/endpointN_sq)*(se_std_sq_sum+`corr'*sumsq_cross_se)) if endpointN!=1
			}
			
			drop exp_se_std
			
			keep registry_expID exp_effect_size exp_se_std* *mean_s`k'
						
			duplicates drop
			isid registry_expID
			foreach var of varlist exp* {
				ren `var' `var'_s`k'
				la var `var'_s`k' "criteria `k': `lab'"
			}
			
			la var behavioral_incent_mean_s`k' "criteria `k': `lab', mean behavioral_incent for collapsed effects"
			la var generalized_mean_s`k' "criteria `k': `lab', mean generalized for collapsed effects"
			la var days_until_meas_mean_s`k' "criteria `k': `lab', mean days_until_meas for collapsed effects"
						
			tempfile criteria`k'
			save `criteria`k'', replace	
		restore
	}
	
	keep registry paperID experimentID paper_authors paper_year registry_paperID ///
		registry_expID contact_duration_best_guess paper_authors_year online_contact
	duplicates drop
	isid registry_expID
	
	forv k=1/`samples' {
		merge 1:1 registry_expID using `criteria`k'', assert(1 3) nogen
	}
	
	save "$datapath/analysis/4_lowe_contact_effects_explvl", replace
	
	* Output to csv ready for Bayesian analysis in R
	keep registry_expID exp_*
	export delimited using "$datapath/analysis/4_lowe_contact_effects_explvl.csv", replace
}
if `biascheck'==1 { // Tests for p-hacking and publication bias
	
	** Experiment-level
	use "$datapath/analysis/4_lowe_contact_effects_explvl", clear

	* Clean
	reg exp_effect_size_s1 exp_se_std`rho'_s1, vce(hc3)
	local slope = string(round(_b[exp_se_std`rho'_s1],0.01))
	local se = string(round(_se[exp_se_std`rho'_s1],0.01))
	
	twoway (lfitci exp_effect_size_s1 exp_se_std`rho'_s1) || ///
			(scatter exp_effect_size_s1 exp_se_std`rho'_s1, msymbol(O) mc(black)), ///
			ytitle("Standardized Effect Size", size(7)) ///
			xtitle("Standard Error", size(7)) legend(off) ///
			ylabel(-0.4(0.2)0.6, labsize(7)) xlabel(, labsize(7)) ///
			title("(a) Experiment-Level, Clean", size(7)) ///
			text(0.3 0.25 "{&beta} = `slope'" "     (`se')", size(7))
	graph export "$figpath/effect_v_se_exp`rho'_clean.pdf", replace	
					
	* Bundled
	reg exp_effect_size_s5 exp_se_std`rho'_s5, vce(hc3)
	local slope = string(round(_b[exp_se_std`rho'_s5],0.01))
	local se = string(round(_se[exp_se_std`rho'_s5],0.01))		
		
	twoway (lfitci exp_effect_size_s5 exp_se_std`rho'_s5) || ///
			(scatter exp_effect_size_s5 exp_se_std`rho'_s5, msymbol(O) mc(black)), ///
			ytitle("Standardized Effect Size", size(7)) ///
			xtitle("Standard Error", size(7)) legend(off) ///
			ylabel(-0.4(0.2)0.6, labsize(7)) xlabel(, labsize(7)) ///			
			title("(a) Experiment-Level, Bundled", size(7))	///		
			text(0.5 0.17 "{&beta} = `slope'" "     (`se')", size(7))	
	graph export "$figpath/effect_v_se_exp`rho'_bundle.pdf", replace	
	
	
	** Effect-level
	use "$datapath/raw/3_lowe_contact_effects", clear
	
	** keep only effects with complete data
	drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
	
	** keep only if pre-registered prior to analysis
	keep if reg_before_analysis==1
	
	** never want the unrelated outcomes
	drop if outcome_type1=="Unrelated" & outcome_type2==""	
	
	* Clean
	reg effect_size se_std if strpos(treatment_comparison,"High versus"), vce(hc3)
	local slope = string(round(_b[se_std],0.01))
	local se = string(round(_se[se_std],0.01))
	
	twoway (lfitci effect_size se_std) || ///
			(scatter effect_size se_std, msymbol(O) mc(black)), ///
			ytitle("Standardized Effect Size", size(7)) ///
			xtitle("Standard Error", size(7)) legend(off) ///
			ylabel(, labsize(7)) xlabel(, labsize(7)) ///
			title("(b) Effect-Level, Clean", size(7)) ///
			text(1.25 0.45 "{&beta} = `slope'" "     (`se')", size(7))
	graph export "$figpath/effect_v_se_eff_clean.pdf", replace
			
	* Bundled
	reg effect_size se_std if strpos(treatment_comparison,"Outgroup contact bundled versus"), vce(hc3)
	local slope = string(round(_b[se_std],0.01))
	local se = string(round(_se[se_std],0.01))
	
	twoway (lfitci effect_size se_std) || ///
			(scatter effect_size se_std, msymbol(O) mc(black)), ///
			ytitle("Standardized Effect Size", size(7)) ///
			xtitle("Standard Error", size(7)) legend(off) ///
			ylabel(, labsize(7)) xlabel(, labsize(7)) ///
			title("(b) Effect-Level, Bundled", size(7)) ///
			text(1.25 0.45 "{&beta} = `slope'" "     (`se')", size(7))
	graph export "$figpath/effect_v_se_eff_bundle.pdf", replace			
	
	
	** Heaping test from Brodeur et al. 2016
	
	* Clean
	twoway (hist tstat if strpos(treatment_comparison,"High versus"), bin(50)) ///
		(kdensity tstat if strpos(treatment_comparison,"High versus"), legend(off) lwidth(1)), ///
		xline(1.96, lwidth(1)) ///
		ytitle("Density", size(7)) ///
		xtitle("t-statistic", size(7)) ///
		ylabel(, labsize(7)) xlabel(0(2)8, labsize(7)) ///
		title("(c) t-statistics, Clean", size(7))
	graph export "$figpath/heap_clean.pdf", replace				
		
	* Bundled
	twoway (hist tstat if strpos(treatment_comparison,"Outgroup contact bundled versus"), bin(50)) ///
		(kdensity tstat if strpos(treatment_comparison,"Outgroup contact bundled versus"), legend(off) lwidth(1)), ///
		xline(1.96, lwidth(1)) ///
		ytitle("Density", size(7)) ///
		xtitle("t-statistic", size(7)) ///
		ylabel(, labsize(7)) xlabel(0(2)8, labsize(7)) ///
		title("(c) t-statistics, Bundled", size(7))		
	graph export "$figpath/heap_bundle.pdf", replace	
	
	* All
	twoway (hist tstat, bin(50)) ///
		(kdensity tstat, legend(off) lwidth(1)), ///
		xline(1.96, lwidth(1)) ///
		ytitle("Density", size(7)) ///
		xtitle("t-statistic", size(7)) ///
		ylabel(, labsize(7)) xlabel(0(2)8, labsize(7)) ///
		title("(d) t-statistics, Clean and Bundled", size(7))		
	graph export "$figpath/heap_all.pdf", replace	
	
	* Clochard (downloaded from Harvard dataverse)
	use "$datapath/raw/Combined_with_experimental", clear
	g tstat = abs(Effect_size/SE_effect)
	twoway (hist tstat if tstat<10, bin(50)) ///
		(kdensity tstat if tstat<10, legend(off) lwidth(1)), ///
		xline(1.96, lwidth(1)) ///
		ytitle("Density", size(7)) ///
		xtitle("t-statistic", size(7)) ///
		ylabel(, labsize(7)) xlabel(0(2)8, labsize(7)) ///
		title("(d) t-statistics, Clochard (2024)", size(7))		
	graph export "$figpath/heap_clochard.pdf", replace
}
if `killerfig'==1 { // Meta-analyse the treatment effects

	/*
	https://stats.oarc.ucla.edu/stata/seminars/introduction-to-meta-analysis-in-stata/
	https://bookdown.org/mbrown35/bookdown-Rguide/setup.html
	*/
		
	use "$datapath/analysis/4_lowe_contact_effects_explvl", clear	

	g tau=.
	g l95=.
	g u95=.
	g isq=.
	g sigma=.
	sort registry_expID
	g order=_n-1	
	
	local plusone = `samples'+1
	
	forv i=1/`samples' {
		meta set exp_effect_size_s`i' exp_se_std`rho'_s`i', studylab(paper_authors_year)
		meta summarize
										
		sort registry_expID
		local j=`plusone'-`i'
		replace tau=r(theta) if order==`j'
		replace l95=r(ci_lb) if order==`j'
		replace u95=r(ci_ub) if order==`j'	
		
		local isq`j'=round(r(I2),1)
		local sigma`j'=round(sqrt(r(tau2)),.01)
		
		replace isq=r(I2) if order==`j'
		replace sigma=sqrt(r(tau2)) if order==`j'
		count if !mi(exp_effect_size_s`i') & !mi(exp_se_std`rho'_s`i')
		local N`j' = r(N)
		
		meta forestplot, xline(0)
				
		graph export "$figpath/lowe_forest_s`i'_rho`rho'.pdf", replace			
	}
	g freq = order<=`samples'
		
	* Get and append R baggr output
	preserve
		import delimited using "$datapath/analysis/baggr_results`rho'.csv", varn(1) clear		
		ren s order
		ren isqmean isq
		replace isq = isq*100
		ren hypersdmean sigma
		replace order = `plusone' - order
		replace order = order - 0.14
		tempfile baggr		
		save `baggr', replace
	restore
	
	keep tau l95 u95 order freq sigma isq
	keep if order<=`samples'
	replace order = -0.7 if order==0
	replace order = order + 0.14	
	append using `baggr'
	sort order
	replace freq=0 if mi(freq)
	
	replace order = order+1 if order>=4.5
	
	twoway scatter order tau if freq==1, ///
		   msize(2.5) mcolor(sea) msymbol(0) || ///
		   scatter order tau if freq==0, ///
		   msize(2.5) mcolor(sky) msymbol(0) || ///
		   rcap l95 u95 order if freq==1, ///
		   msize(2.5) lwidth(1) lcolor(sea) hor || ///
		   rcap l95 u95 order if freq==0, ///
		   msize(2.5) lwidth(1) lcolor(sky) ///
		   hor legend(order(1 2) rows(1) label(1 "Frequentist") label(2 "Bayesian") size(5) ///
		   pos(0) bplacement(seast) ring(1)) ///
		   ytitle("") ///
		   xlabel(-0.05 0 0.05 0.1 0.15 0.2 0.25 0.3, labsize(5) notick) ///
		   ylabel(1 `" "+ Long" "{it:N = `N1'}" "' ///
				  2 `" "+ Optimal" "{it:N = `N2'}" "' ///
				  3 `" "Generalized" "{it:N = `N3'}" "' ///
			      4 `" "All" "{it:N = `N4'}" "' ///
				  6 `" "+ Long" "{it:N = `N5'}" "' ///				  
				  7 `" "+ Optimal" "{it:N = `N6'}" "' ///
				  8 `" "Generalized" "{it:N = `N7'}" "' ///
				  9 `" "All" "{it:N = `N8'}" "' ///
				  , labsize(5) notick nogrid) ///
		   xline(0, lwidth(1) lcolor(grey%20)) ///
		   xtitle("Standardized Effect", size(5)) ///
		   ysize(10) xsize(8) ///
		   yscale(lstyle(none)) ///
		   xscale(lstyle(none)) ///
		   title("", size(5) margin(b=0.5cm)) ///   
		   saving(meta_mean.gph, replace)
	g order2 = order+0.28
	
	twoway scatter order2 sigma if freq==0, ///
		   msize(2.5) mcolor(teal) msymbol(0) || ///
		   rbar postpredl50 postpredmean order if freq==0, ///
		   hor color(eltgreen) lcolor(black) barw(0.2) || ///	
		   rbar postpredmean postpredu50 order if freq==0, ///
		   hor color(eltgreen) lcolor(black) barw(0.2) || ///	
		   rspike postpredl95 postpredl50 order if freq==0, ///
		   hor color(black) || ///
		   rspike postpredu50 postpredu95 order if freq==0, ///
		   hor color(black) || ///		   
		   rcap hypersdl95 hypersdu95 order2 if freq==0, ///
		   hor msize(2.5) lwidth(1) lcolor(teal) ///
		   legend(order(1 2) rows(1) label(1 "{&sigma}") label(2 "Predictive" "Interval") size(5) ///
		   pos(0) bplacement(seast) ring(1)) ///		   
		   ytitle("") ///
		   xlabel(-0.2 -0.1 0 0.1 0.2 0.3 0.4 0.5, labsize(5) notick) ///
		   ylabel(, nolab notick nogrid) ///
		   xline(0, lwidth(1) lcolor(grey%20)) ///
		   xtitle("Standardized Effect", size(5)) ///
		   ysize(10) xsize(3) ///
		   yscale(lstyle(none)) ///
		   xscale(lstyle(none)) /// 		   
		   fxsize(50) ///
		   text(10 -0.5 "(a) Clean Interventions", size(5) fc(white) lcolor(white) justification(center) box) ///	
		   text(5 -0.5 "(b) Bundled Interventions", size(5) fc(white) lcolor(white) justification(center) box) ///				   
		   title("", size(5) margin(b=0.5cm)) ///	 		   
		   saving(meta_het.gph, replace)	
		   				
	graph combine meta_mean.gph meta_het.gph, ///
		ycom imargin(10 0 0 0) graphregion(margin(l=-10))
	graph export "$figpath/lowe_meta_rho`rho'.pdf", replace	
	
	erase meta_mean.gph 
	erase meta_het.gph
}
if `genprob'==1 { // Effect-level regressions to look at generalized vs. specific, etc.
	
	** Effect-level
	use "$datapath/raw/3_lowe_contact_effects", clear
	
	** keep only effects with complete data
	drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
	
	** keep only if pre-registered prior to analysis
	keep if reg_before_analysis==1
	
	** never want the unrelated outcomes
	drop if outcome_type1=="Unrelated" & outcome_type2==""	
	
	** keep only treatment comparisons about outgroup contact
	keep if strpos(treatment_comparison,"High versus") | strpos(treatment_comparison,"Outgroup contact bundled")
	
	replace generalized=0 if mi(generalized)
		
	** Generalized vs. specific outcomes	
	areg effect_size generalized [aw=1/var_std] if strpos(treatment_comparison,"High versus"), ///
		absorb(registry_expID) vce(robust)		
	est sto G1
	local obs1 = string(e(N),"%9.0gc")
	qui su effect_size if e(sample)==1 & generalized==0
	local specmean1 = string(r(mean),"%9.2f")	
	
	* How many experiments contribute identifying variation?
	bys registry_expID: egen meanTmp = mean(generalized) if e(sample)==1
	distinct registry_expID if meanTmp>0 & meanTmp<1
	drop meanTmp
					
	areg effect_size generalized immediate months_until_measurement behavioral_incent [aw=1/var_std] if strpos(treatment_comparison,"High versus"), ///
		absorb(registry_expID) vce(robust)	
	est sto G2
	local obs2 = string(e(N),"%9.0gc")
	qui su effect_size if e(sample)==1 & generalized==0
	local specmean2 = string(r(mean),"%9.2f")		
		
	areg effect_size generalized [aw=1/var_std] if strpos(treatment_comparison,"Outgroup contact bundled"), ///
		absorb(registry_expID) vce(robust)	
	est sto G3
	local obs3 = string(e(N),"%9.0gc")
	qui su effect_size if e(sample)==1 & generalized==0
	local specmean3 = string(r(mean),"%9.2f")		
	
	* How many experiments contribute identifying variation?
	bys registry_expID: egen meanTmp = mean(generalized) if e(sample)==1
	distinct registry_expID if meanTmp>0 & meanTmp<1
	drop meanTmp	
			
	areg effect_size generalized immediate months_until_measurement behavioral_incent [aw=1/var_std] ///
		if strpos(treatment_comparison,"Outgroup contact bundled"), absorb(registry_expID) vce(robust)	
	est sto G4
	local obs4 = string(e(N),"%9.0gc")
	qui su effect_size if e(sample)==1 & generalized==0
	local specmean4 = string(r(mean),"%9.2f")
			
	** table
	estout G1 G2 G3 G4 using "$tabpath/genprobA.tex", style(tex) replace ///
	keep(generalized immediate months_until_measurement behavioral_incent) cells(b(star fmt(%9.2f)) se(par)) ///
	nolabel collabels(none) mlabels(none) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	varlabels(generalized "Generalized Outcome (0/1)" immediate "Same-Day Measurement (0/1)" ///
		months_until_measurement "Months Until Measurement" ///
		behavioral_incent "Incentivized Outcome (0/1)")

	local tex "\input{Tables/genprobA} \\ \hline"
	local tex "`tex' Observations & `obs1' & `obs2' & `obs3' & `obs4' \\" 
	local tex "`tex' Non-Generalized Outcome Mean & `specmean1' & `specmean2' & `specmean3' & `specmean4' \\" 
	local tex "`tex' Experiment Fixed Effects & Yes & Yes & Yes & Yes \\"
	local tex "`tex' Inverse Variance-Weighted & Yes & Yes & Yes & Yes \\ \toprule"
	local tex "`tex' \multicolumn{5}{p{13cm}}{\footnotesize \textit{Notes:}"
	local tex "`tex' The unit of observation is the treatment effect."
	local tex "`tex' Columns 1 and 2 consider predictors of the standardized effects of clean contact interventions, while columns 3 and 4 consider bundled interventions."
	local tex "`tex' Generalized is a dummy variable equal to one if the outcome is generalized to the broader outgroup, as opposed to including the specific outgroup members met during the intervention. In rare cases where the outcome is an index with a mix of generalized and non-generalized components, Generalized is set equal to 0.5."
	local tex "`tex' Observations are weighted by the inverse of the standardized standard error squared."
	local tex "`tex' Standard errors are robust."
	local tex "`tex' *** p<0.01, ** p<0.05, * p<0.1.} \\"
	local tex "`tex' \end{tabular} }"

	esttab G1 G2 G3 G4 using "$tabpath/genprob.tex", style(tex) booktabs replace ///
		d(*) nolabel collabels(none) noobs nonum postfoot("`tex'") ///
		mgroups("Clean Effect Size" "Bundled Effect Size", pattern(1 0 1 0) ///
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///		
		mtitles("(1)" "(2)" "(3)" "(4)")
}
if `bundVclean'==1 { // Effect of bundled vs. clean interventions
	
	** Effect-level
	use "$datapath/raw/3_lowe_contact_effects", clear
	
	** keep only effects with complete data
	drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
	
	** keep only if pre-registered prior to analysis
	keep if reg_before_analysis==1
	
	** never want the unrelated outcomes
	drop if outcome_type1=="Unrelated" & outcome_type2==""	
	
	** drop ingroup bundled comparisons
	drop if strpos(treatment_comparison,"Ingroup contact bundled")	
	
	** Bundled vs. clean	
	areg effect_size bundled_out [aw=1/var_std], absorb(registry_expID) vce(robust)	
	est sto B1
	local obs1 = string(e(N),"%9.0gc")
	qui su effect_size if e(sample)==1 & bundled_out==0
	local cleanmean1 = string(r(mean),"%9.2f")		
	
	areg effect_size bundled_out generalized immediate months_until_measurement behavioral_incent [aw=1/var_std], absorb(registry_expID) vce(robust)	
	est sto B2
	local obs2 = string(e(N),"%9.0gc")
	qui su effect_size if e(sample)==1 & bundled_out==0
	local cleanmean2 = string(r(mean),"%9.2f")	
	
	** table
	estout B1 B2 using "$tabpath/bundVcleanA.tex", style(tex) replace ///
	keep(bundled_out) cells(b(star fmt(%9.2f)) se(par)) ///
	nolabel collabels(none) mlabels(none) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	varlabels(bundled_out "Bundled Outgroup Contact vs. Control")

	local tex "\input{Tables/bundVcleanA} \\ \hline"
	local tex "`tex' Observations & `obs1' & `obs2' \\" 
	local tex "`tex' Clean Effect Mean & `cleanmean1' & `cleanmean2' \\" 
	local tex "`tex' Experiment Fixed Effects & Yes & Yes \\"
	local tex "`tex' Weighted & Yes & Yes \\"
	local tex "`tex' Controls & No & Yes \\ \toprule"	
	local tex "`tex' \multicolumn{3}{p{9.3cm}}{\footnotesize \textit{Notes:}"
	local tex "`tex' The unit of observation is the treatment effect."
	local tex "`tex' The sample includes only the effects of clean contact and bundled outgroup interventions."
	local tex "`tex' The key regressor is a dummy variable equal to one for the effects of bundled outgroup interventions, and equal to zero for the effects of clean contact interventions."
	local tex "`tex' Observations are weighted by the inverse of the standardized standard error squared."
	local tex "`tex' Controls are (i) a dummy variable for whether the outcome is generalized to the outgroup as a whole (coded as 0.5 for rare cases in which the outcome is an index containing both generalized and non-generalized outcomes), (ii) a dummy variable for whether the outcome was measured immediately after the contact intervention, (iii) the number of months between the end of the intervention and the outcome measurement, and (iv) a dummy variable for whether the outcome is incentivized/behavioral or not."
	local tex "`tex' Standard errors are robust."
	local tex "`tex' *** p<0.01, ** p<0.05, * p<0.1.} \\"
	local tex "`tex' \end{tabular} }"

	esttab B1 B2 using "$tabpath/bundVclean.tex", style(tex) booktabs replace ///
		d(*) nolabel collabels(none) noobs nonum postfoot("`tex'") ///
		mgroups("Effect Size", pattern(1 0) ///
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///		
		mtitles("(1)" "(2)")	
		
}
if `exphet'==1 { // What predicts experiment-level variation in effects?

	** Get N for each experiment
	use "$datapath/raw/2_lowe_contact_studies", clear
	keep registry paperID mean_age1 mean_age2
	tempfile age
	save `age', replace

	** Get experiment-level estimates to merge on
	use "$datapath/analysis/4_lowe_contact_effects_explvl", clear
	keep registry paperID experimentID registry_expID exp_* *mean*
	merge m:1 registry paperID using `age', assert(3) nogen
	replace mean_age1=mean_age2 if experimentID==2
	drop mean_age2
	ren mean_age1 mean_age
	replace mean_age=. if mean_age==-99 // age not used in regs in paper, but here for ppl to explore (anyway, it appears not to be predictive)
	tempfile expest
	save `expest', replace

	** Effect-level
	use "$datapath/raw/3_lowe_contact_effects", clear
	
	** keep only effects with complete data
	drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
	
	** keep only if pre-registered prior to analysis
	keep if reg_before_analysis==1
	
	** never want the unrelated outcomes
	drop if outcome_type1=="Unrelated" & outcome_type2==""
	
	** don't want effects of ingroup contact
	drop if bundled_in==1
	
	** merge on experiment-level stuff
	merge m:1 registry_expID using `expest', assert(3) nogen
	
	** keep experiment-level stuff
	keep registry_expID contact_duration_best_guess allport_conditions online_contact exp_* *mean*
	duplicates drop
	isid registry_expID
	
	foreach var of varlist exp_se_std12* {
		g `var'sq = `var'^2
	}
	
	g lduration = ln(contact_duration_best_guess)
	
	** clean effects
	reg exp_effect_size_s1 lduration allport_conditions online_contact [aw=1/exp_se_std12_s1sq], vce(hc3)
	est sto O1
	local obs1 = string(e(N),"%9.0gc")
	qui su exp_effect_size_s1 if e(sample)==1
	local mean1 = string(r(mean),"%9.2f")		
	
	reg exp_effect_size_s1 lduration allport_conditions online_contact ///
		behavioral_incent_mean_s1 generalized_mean_s1 days_until_meas_mean_s1 [aw=1/exp_se_std12_s1sq], vce(hc3)	
	est sto O2
	local obs2 = string(e(N),"%9.0gc")
	qui su exp_effect_size_s1 if e(sample)==1
	local mean2 = string(r(mean),"%9.2f")		
	
	** bundled effects
	reg exp_effect_size_s5 lduration allport_conditions online_contact [aw=1/exp_se_std12_s5sq], vce(hc3)
	est sto O3
	local obs3 = string(e(N),"%9.0gc")
	qui su exp_effect_size_s5 if e(sample)==1
	local mean3 = string(r(mean),"%9.2f")	
	
	reg exp_effect_size_s5 lduration allport_conditions online_contact ///
		behavioral_incent_mean_s5 generalized_mean_s5 days_until_meas_mean_s5 [aw=1/exp_se_std12_s5sq], vce(hc3)	
	est sto O4
	local obs4 = string(e(N),"%9.0gc")
	qui su exp_effect_size_s5 if e(sample)==1
	local mean4 = string(r(mean),"%9.2f")	
	
	** pooled effects
	preserve
		keep registry_expID-exp_se_std80_s1 exp_se_std12_s1sq lduration 
		foreach var of varlist *s1 {
			local newname = substr("`var'",1,length("`var'")-1)
			ren `var' `newname'
		}
		g clean=1
		ren exp_se_std12_s1sq exp_se_std12_ssq
		tempfile s1
		save `s1'
	restore	
	
	preserve
		keep registry_expID-allport_conditions *s5* lduration 
		foreach var of varlist *s5 {
			local newname = substr("`var'",1,length("`var'")-1)
			ren `var' `newname'
		}
		ren exp_se_std12_s5sq exp_se_std12_ssq
		g clean=0
		append using `s1'
				
		reg exp_effect_size_s lduration allport_conditions online_contact clean [aw=1/exp_se_std12_ssq], cluster(registry_expID)
		est sto O5
		local obs5 = string(e(N),"%9.0gc")
		qui su exp_effect_size_s if e(sample)==1
		local mean5 = string(r(mean),"%9.2f")	
			
		reg exp_effect_size_s lduration allport_conditions online_contact clean ///
			behavioral_incent_mean_s generalized_mean_s days_until_meas_mean_s [aw=1/exp_se_std12_ssq], cluster(registry_expID)
		est sto O6
		local obs6 = string(e(N),"%9.0gc")
		qui su exp_effect_size_s if e(sample)==1
		local mean6 = string(r(mean),"%9.2f")			
	restore		
		
		
	** table
	estout O1 O2 O3 O4 O5 O6 using "$tabpath/exphetA.tex", style(tex) replace ///
	keep(lduration allport_conditions online_contact) cells(b(star fmt(%9.2f)) se(par)) ///
	nolabel collabels(none) mlabels(none) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	varlabels(lduration "ln(Hours of Intergroup Contact)" ///
		allport_conditions "Number of Allport Conditions Met (0 to 4)" ///
		online_contact "Online Contact (0/1)")

	local tex "\input{Tables/exphetA} \\ \hline"
	local tex "`tex' Observations & `obs1' & `obs2' & `obs3' & `obs4' & `obs5' & `obs6' \\" 
	local tex "`tex' Outcome Mean & `mean1' & `mean2' & `mean3' & `mean4' & `mean5' & `mean6' \\" 
	local tex "`tex' Controls & No & Yes & No & Yes & No & Yes \\"
	local tex "`tex' Clean Effect Dummy & No & No & No & No & Yes & Yes \\"
	local tex "`tex' Inverse Variance-Weighted & Yes & Yes & Yes & Yes & Yes & Yes \\ \toprule"
	local tex "`tex' \multicolumn{7}{p{18cm}}{\footnotesize \textit{Notes:}"
	local tex "`tex' The outcome is the experiment-level treatment effect size."
	local tex "`tex' Columns 1 and 2 consider predictors of the standardized effects of clean contact interventions, while columns 3 and 4 consider bundled interventions. Columns 5 and 6 pool include both sets of treatment effects, adding a dummy variable for whether the effect is clean or bundled."
	local tex "`tex' Online contact is equal to one for the seven experiments with intergroup contact taking place online, and equal to zero for experiments with in-person intergroup contact."
	local tex "`tex' Controls are (i) fraction of underlying outcomes that are incentivized, (ii) fraction of underlying outcomes that are generalized,"
	local tex "`tex' and (iii) average days between end of intervention and outcome measurement for underlying outcomes."
	local tex "`tex' Observations are weighted by the inverse of the standardized standard error squared."
	local tex "`tex' Standard errors are robust in columns 1 to 4, otherwise clustered at experiment-level."
	local tex "`tex' *** p<0.01, ** p<0.05, * p<0.1.} \\"
	local tex "`tex' \end{tabular} }"

	esttab O1 O2 O3 O4 O5 O6 using "$tabpath/exphet.tex", style(tex) booktabs replace ///
		d(*) nolabel collabels(none) noobs nonum postfoot("`tex'") ///
		mgroups("Clean Effect Size" "Bundled Effect Size" "All Effects", pattern(1 0 1 0 1 0) ///
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///		
		mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(6)")	
}
if `globalsouth'==1 { // Are effects in the Global South smaller?

	** Get experiment-level estimates to merge on
	use "$datapath/analysis/4_lowe_contact_effects_explvl", clear
	keep registry_expID exp_* *mean*
	tempfile expest
	save `expest', replace

	** Effect-level
	use "$datapath/raw/3_lowe_contact_effects", clear
	
	** keep only effects with complete data
	drop if mi(effect_size) | effect_size==-99 | mi(se_std) | se_std==-99
	
	** keep only if pre-registered prior to analysis
	keep if reg_before_analysis==1
	
	** never want the unrelated outcomes
	drop if outcome_type1=="Unrelated" & outcome_type2==""
	
	** don't want effects of ingroup contact
	drop if bundled_in==1
	
	** merge on experiment-level stuff
	merge m:1 registry_expID using `expest', assert(3) nogen
	
	** keep experiment-level stuff
	keep registry_expID contact_duration_best_guess allport_conditions online_contact exp_* *mean* global_south
	duplicates drop
	isid registry_expID
	
	foreach var of varlist exp_se_std12* {
		g `var'sq = `var'^2
	}
	
	g lduration = ln(contact_duration_best_guess)
	
	** pooled effects
	preserve
		keep registry_expID-exp_se_std80_s1 exp_se_std12_s1sq lduration 
		foreach var of varlist *s1 {
			local newname = substr("`var'",1,length("`var'")-1)
			ren `var' `newname'
		}
		g clean=1
		ren exp_se_std12_s1sq exp_se_std12_ssq
		tempfile s1
		save `s1'
	restore	
	
	preserve
		keep registry_expID-global_south *s5* lduration 
		foreach var of varlist *s5 {
			local newname = substr("`var'",1,length("`var'")-1)
			ren `var' `newname'
		}
		ren exp_se_std12_s5sq exp_se_std12_ssq
		g clean=0
		append using `s1'
				
		reg exp_effect_size_s global_south clean [aw=1/exp_se_std12_ssq], cluster(registry_expID)
		est sto O1
		local obs1 = string(e(N),"%9.0gc")
		qui su exp_effect_size_s if e(sample)==1
		local mean1 = string(r(mean),"%9.2f")			
		
		reg exp_effect_size_s global_south lduration allport_conditions online_contact clean [aw=1/exp_se_std12_ssq], cluster(registry_expID)
		est sto O2
		local obs2 = string(e(N),"%9.0gc")
		qui su exp_effect_size_s if e(sample)==1
		local mean2 = string(r(mean),"%9.2f")	
			
		reg exp_effect_size_s global_south lduration allport_conditions online_contact clean ///
			behavioral_incent_mean_s generalized_mean_s days_until_meas_mean_s [aw=1/exp_se_std12_ssq], cluster(registry_expID)
		est sto O3
		local obs3 = string(e(N),"%9.0gc")
		qui su exp_effect_size_s if e(sample)==1
		local mean3 = string(r(mean),"%9.2f")			
	restore		
		
	** table
	estout O1 O2 O3 using "$tabpath/globalsouthA.tex", style(tex) replace ///
	keep(global_south) cells(b(star fmt(%9.2f)) se(par)) ///
	nolabel collabels(none) mlabels(none) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	varlabels(global_south "Experiment in Global South (0/1)")

	local tex "\input{Tables/globalsouthA} \\ \hline"
	local tex "`tex' Observations & `obs1' & `obs2' & `obs3' \\" 
	local tex "`tex' Outcome Mean & `mean1' & `mean2' & `mean3' \\" 
	local tex "`tex' Controls & No & Some & Full \\"
	local tex "`tex' Clean Effect Dummy & Yes & Yes & Yes \\"
	local tex "`tex' Inverse Variance-Weighted & Yes & Yes & Yes \\ \toprule"
	local tex "`tex' \multicolumn{4}{p{10cm}}{\footnotesize \textit{Notes:}"
	local tex "`tex' The outcome is the experiment-level treatment effect size."
	local tex "`tex' I include the effects of both clean and bundled interventions, and include a dummy variable for whether the effect is clean or bundled."
	local tex "`tex' Experiment in Global South is equal to one if the experiment took place in the Global South and zero otherwise."
	local tex "`tex' Some Controls are (i) ln duration of contact in hours, (ii) the number of Allport conditions met (0 to 4), and (iii) whether the contact is online or not."
	local tex "`tex' Full Controls include in addition (i) the fraction of underlying outcomes that are incentivized, (ii) the fraction of underlying outcomes that are generalized, and (iii) the average days between end of intervention and outcome measurement for the underlying outcomes."
	local tex "`tex' Observations are weighted by the inverse of the standardized standard error squared."
	local tex "`tex' Standard errors are clustered at experiment-level."
	local tex "`tex' *** p<0.01, ** p<0.05, * p<0.1.} \\"
	local tex "`tex' \end{tabular} }"

	esttab O1 O2 O3 using "$tabpath/globalsouth.tex", style(tex) booktabs replace ///
		d(*) nolabel collabels(none) noobs nonum postfoot("`tex'") ///
		mgroups("Experiment Effect Size", pattern(1 0 0) ///
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///		
		mtitles("(1)" "(2)" "(3)")
}
if `onlineVoff'==1 { // Graphing the effects of online vs. in-person contact

use "$datapath/analysis/4_lowe_contact_effects_explvl", clear
	
forv i=1/8 {
	g u95_s`i' = exp_effect_size_s`i' + 1.96*exp_se_std12_s`i'
	g l95_s`i' = exp_effect_size_s`i' - 1.96*exp_se_std12_s`i'	
}

* jitter
set seed 10354
g random=runiform()
g duration_jitter = contact_duration_best_guess
replace duration_jitter = duration_jitter*(1.5-random)

local title1 "(a) Clean Interventions"
local title5 "(b) Bundled Interventions"

foreach x in 1 5 {
	twoway scatter exp_effect_size_s`x' duration_jitter if online_contact==0, ///
		msize(2) mcolor(black) msymbol(0) || ///
		rcap l95_s`x' u95_s`x' duration_jitter if online_contact==0, ///
		msize(2) lwidth(0.75) lcolor(black) || ///
		rcap l95_s`x' u95_s`x' duration_jitter if online_contact==1, ///	
		msize(2) lwidth(0.75) lcolor(sea) || ///
		scatter exp_effect_size_s`x' duration_jitter if online_contact==1, ///
		msize(2) mcolor(sea) msymbol(0) xscale(log range(0.1 1000) noline)  ///			
		yscale(noline) ///
		ylabel(,labsize(5)) ///
		xlabel(0.1 1 10 100 1000, labsize(5)) ///
		legend(order(1 4) rows(1) label(1 "In-Person") label(4 "Online") size(5) ///
		pos(5) ring(0)) ///
		ytitle("Standardized Effect Size", size(5)) ///
		xtitle("Duration of Intergroup Contact (Hours)", size(5)) ///
		title("`title`x''", size(5)) ///
		yline(0, lwidth(0.7) lcolor(grey%20)) ///
		saving(online`x'.gph, replace)
}

graph combine online1.gph online5.gph, ///
	ycom imargin(10 0 0 0) graphregion(margin(l=-10)) xsize(10)
graph export "$figpath/lowe_onlineVoffline.pdf", replace	

erase online1.gph 
erase online5.gph	
}
if `compare_clochard'==1 { // Clochard vs. my approach using only overlapping papers

** What average effect would I estimate using my approach only the 13 papers that overlap with Clochard (2024)?
use "$datapath/analysis/4_lowe_contact_effects_explvl", clear	
	
merge m:1 registry paperID using "$datapath/raw/2_lowe_contact_studies", keepusing(in_clochard) assert(3)	
	
** Use clean comparison if available, otherwise use bundled comparison
g exp_effect_size = exp_effect_size_s1
replace exp_effect_size = exp_effect_size_s5 if mi(exp_effect_size)

g exp_se_std12 = exp_se_std12_s1
replace exp_se_std12 = exp_se_std12_s5 if mi(exp_se_std12)

** Now aggregate using frequentist approach
meta set exp_effect_size exp_se_std12 if in_clochard==1, studylab(paper_authors_year)
meta summarize // 0.035, CI: -0.021 to 0.092

meta set exp_effect_size exp_se_std12 if in_clochard==0, studylab(paper_authors_year)
meta summarize // 0.14, CI: 0.083 to 0.198

** Now apply Clochard (2024) method (downloaded his data from Harvard dataverse)
use "$datapath/raw/Combined_with_experimental", clear

* Replicate his main result (effect size = 0.224)
metan std_effect std_se, ///
	npts(N) /// Defines the number of observations
	lcols(Name_measure) /// Defines the name of papers
	graphregion(color(white)) /// 
	random

* Keep only papers that overlap with my set
keep if Title=="Durably reducing transphobia: A field experiment on door-to-door canvassing" | ///
	Title=="The economic effects of inter-sectarian contact" | ///
	Title=="Improving the Perception of the Police by the Youth" | ///
	Title=="Does integration change gender attitudes? The effect of randomly assigning women to traditionally male teams." | ///
	strpos(Title,"Rearranging the Desk Chairs")>0 | ///
	Title=="Does personal contact with ethnic minorities affect anti-immigrant sentiments? Evidence from a field experiment" | ///
	Title=="Brief cooperative contact with ethnic minorities reduces discrimination" | ///
	Title=="Creating Cohesive Communities: A Youth Camp Experiment in India" | ///
	Title=="Reducing Exclusionary Attitudes through Interpersonal Conversation: Evidence from Three Field Experiments" | ///
	Title=="Types of Contact: A Field Experiment on Collaborative and Adversarial Caste Integration" | ///
	Title=="Building social cohesion between Christians and Muslims through soccer in post-ISIS Iraq" | ///
	Title=="Can Social Contact Reduce Prejudice and Discrimination? Evidence from a Field Experiment in Nigeria" | ///
	strpos(Title,"Prolonged Contact Does Not Reshape")>0
distinct Title
assert r(ndistinct)==13

* His method applied only to overlapping sample
metan std_effect std_se, ///
	npts(N) /// Defines the number of observations
	lcols(Name_measure) /// Defines the name of papers
	graphregion(color(white)) /// 
	random // (effect size = 0.115)

}
beep